# This file was auto-generated by Fern from our API Definition.

import typing
from .jpeg import Jpeg
from .png import Png

HealthInsuranceCreateRequestPatientSignatureImage = typing.Union[Jpeg, Png]
