# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.query_batch_timeframe import QueryBatchTimeframe
from ..types.query import Query
from ..types.query_config import QueryConfig
from ..core.request_options import RequestOptions
from ..types.aggregation_response import AggregationResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AggregateClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def query_one(
        self,
        user_id: str,
        *,
        timeframe: QueryBatchTimeframe,
        queries: typing.Sequence[Query],
        config: typing.Optional[QueryConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AggregationResponse:
        """
        Parameters
        ----------
        user_id : str

        timeframe : QueryBatchTimeframe

        queries : typing.Sequence[Query]

        config : typing.Optional[QueryConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AggregationResponse
            Successful Response

        Examples
        --------
        from vital import (
            AggregateExpr,
            AggregateExprFunc,
            Period,
            PeriodUnit,
            Query,
            RelativeTimeframe,
            SleepColumnExpr,
            SleepColumnExprSleep,
            Vital,
        )

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.aggregate.query_one(
            user_id="user_id",
            timeframe=RelativeTimeframe(
                anchor="anchor",
                past=Period(
                    unit=PeriodUnit.MINUTE,
                ),
            ),
            queries=[
                Query(
                    select=[
                        AggregateExpr(
                            arg=SleepColumnExpr(
                                sleep=SleepColumnExprSleep.SESSION_START,
                            ),
                            func=AggregateExprFunc.MEAN,
                        )
                    ],
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"aggregate/v1/user/{jsonable_encoder(user_id)}/query",
            method="POST",
            json={
                "timeframe": timeframe,
                "queries": queries,
                "config": config,
            },
            headers={
                "accept": "*/*",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AggregationResponse,
                    parse_obj_as(
                        type_=AggregationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncAggregateClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def query_one(
        self,
        user_id: str,
        *,
        timeframe: QueryBatchTimeframe,
        queries: typing.Sequence[Query],
        config: typing.Optional[QueryConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AggregationResponse:
        """
        Parameters
        ----------
        user_id : str

        timeframe : QueryBatchTimeframe

        queries : typing.Sequence[Query]

        config : typing.Optional[QueryConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AggregationResponse
            Successful Response

        Examples
        --------
        import asyncio

        from vital import (
            AggregateExpr,
            AggregateExprFunc,
            AsyncVital,
            Period,
            PeriodUnit,
            Query,
            RelativeTimeframe,
            SleepColumnExpr,
            SleepColumnExprSleep,
        )

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.aggregate.query_one(
                user_id="user_id",
                timeframe=RelativeTimeframe(
                    anchor="anchor",
                    past=Period(
                        unit=PeriodUnit.MINUTE,
                    ),
                ),
                queries=[
                    Query(
                        select=[
                            AggregateExpr(
                                arg=SleepColumnExpr(
                                    sleep=SleepColumnExprSleep.SESSION_START,
                                ),
                                func=AggregateExprFunc.MEAN,
                            )
                        ],
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"aggregate/v1/user/{jsonable_encoder(user_id)}/query",
            method="POST",
            json={
                "timeframe": timeframe,
                "queries": queries,
                "config": config,
            },
            headers={
                "accept": "*/*",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AggregationResponse,
                    parse_obj_as(
                        type_=AggregationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
