# This file was auto-generated by Fern from our API Definition.

import typing
from .providers import Providers
from .labs import Labs

ClientFacingElectrocardiogramSourceProvider = typing.Union[Providers, Labs]
