# This file was auto-generated by Fern from our API Definition.

import typing
from .index_column_expr import IndexColumnExpr
from .placeholder import Placeholder

DatePartExprArg = typing.Union[IndexColumnExpr, Placeholder]
