# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PayorCodeExternalProvider(str, enum.Enum):
    CHANGE_HEALTHCARE = "change_healthcare"
    AVAILITY = "availity"

    def visit(
        self, change_healthcare: typing.Callable[[], T_Result], availity: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is PayorCodeExternalProvider.CHANGE_HEALTHCARE:
            return change_healthcare()
        if self is PayorCodeExternalProvider.AVAILITY:
            return availity()
