# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.relative_timeframe import RelativeTimeframe
from ...types.placeholder import Placeholder

QueryBatchTimeframe = typing.Union[RelativeTimeframe, Placeholder]
