# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .energy import Energy
from .macros import Macros
from .micros import Micros
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingFood(UniversalBaseModel):
    energy: typing.Optional[Energy] = None
    macros: typing.Optional[Macros] = None
    micros: typing.Optional[Micros] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
